#ifndef NT2_INCLUDE_FUNCTIONS_DEFINITELY_GREATER_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_DEFINITELY_GREATER_HPP_INCLUDED

#include <nt2/fuzzy/include/functions/definitely_greater.hpp>

#endif
